==> haskell-stm-containers-1.2.0.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-containers
version:              1.2.0.1
visibility:           public
id:                   stm-containers-1.2.0.1-7lMC7DPQmuwCbYnbBWHC9b
key:                  stm-containers-1.2.0.1-7lMC7DPQmuwCbYnbBWHC9b
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-containers
synopsis:             Containers for STM
description:
    This library is based on an STM-specialized implementation of
    Hash Array Mapped Trie.
    It provides efficient implementations of @Map@, @Set@
    and other data structures,
    which starting from version @1@ perform even better than their counterparts from \"unordered-containers\",
    but also scale well on concurrent access patterns.
    .
    For details on performance of the library, which are a bit outdated, see
    <http://nikita-volkov.github.io/stm-containers/ this blog post>.

category:             Data Structures, STM, Concurrency
abi:                  ab7bcb164b7a346ae107f4e7cadd9bc6
exposed:              True
exposed-modules:
    StmContainers.Bimap StmContainers.Map StmContainers.Multimap
    StmContainers.Set

hidden-modules:       StmContainers.Prelude
import-dirs:          /usr/lib/ghc-9.0.2/site-local/stm-containers-1.2.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/stm-containers-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-containers
hs-libraries:         HSstm-containers-1.2.0.1-7lMC7DPQmuwCbYnbBWHC9b
depends:
    base-4.15.1.0 deferred-folds-0.9.18.3-6tnDMkkH6QMGKYMMkiR9Pr
    focus-1.0.3.1-9lMjQmEzpi8DkHbIy50AZE
    hashable-1.4.3.0-ESEjVh9IF6l3kXlrvIyche
    list-t-1.0.5.4-IDEN3pFNRPWD83XoREpOs9
    stm-hamt-1.2.0.12-Azkr8TwkHFxFTFXhF6eM8o transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-stm-containers/html/stm-containers.haddock

haddock-html:         /usr/share/doc/haskell-stm-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-containers-1.2.0.3-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-containers
version:              1.2.0.3
visibility:           public
id:                   stm-containers-1.2.0.3-7MoD3bIAfiq1DdVLsOaXA9
key:                  stm-containers-1.2.0.3-7MoD3bIAfiq1DdVLsOaXA9
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-containers
synopsis:             Containers for STM
description:
    This library is based on an STM-specialized implementation of
    Hash Array Mapped Trie.
    It provides efficient implementations of @Map@, @Set@
    and other data structures,
    which starting from version @1@ perform even better than their counterparts from \"unordered-containers\",
    but also scale well on concurrent access patterns.
    .
    For details on performance of the library, which are a bit outdated, see
    <http://nikita-volkov.github.io/stm-containers/ this blog post>.

category:             Data Structures, STM, Concurrency
abi:                  195764e314c46f136e43ba185a7ca834
exposed:              True
exposed-modules:
    StmContainers.Bimap StmContainers.Map StmContainers.Multimap
    StmContainers.Set

hidden-modules:       StmContainers.Prelude
import-dirs:          /usr/lib/ghc-9.0.2/site-local/stm-containers-1.2.0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/stm-containers-1.2.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-containers
hs-libraries:         HSstm-containers-1.2.0.3-7MoD3bIAfiq1DdVLsOaXA9
depends:
    base-4.15.1.0 deferred-folds-0.9.18.6-BAdT3R2KeTYJXQZ4rrtCjd
    focus-1.0.3.2-D5SPk4UVGx2F1Z82JrAdwZ
    hashable-1.4.3.0-JNIl3QAmQdVCUYfpxV7wfJ
    list-t-1.0.5.4-DMPTpOPo8YeJrKNQddDZJa
    stm-hamt-1.2.0.14-GjEPjGwylDtDppD5KZhvdY transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-stm-containers/html/stm-containers.haddock

haddock-html:         /usr/share/doc/haskell-stm-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
